var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import chalk from 'chalk';
import path from 'path';
import config from '../config';
import { info, success, error } from '../utils/console';
import { move } from '../utils/files';
import { cloneRepository, parseRepository } from '../utils/github';
import { npmInstall, updatePackage } from '../utils/packages';
export default (namespace, logs = true) => __awaiter(this, void 0, void 0, function* () {
    if (namespace.includes('/')) {
        // Probably the package is from a GitHub repo.
        info(chalk `Installing {underline.bold ${namespace}}...`, logs);
        const { name, branch } = parseRepository(namespace);
        try {
            const oldDir = path.resolve(config.path, `${name}-${branch}`);
            const dir = path.resolve(config.path, `${name}`);
            info('Cloning repository from GitHub...', logs);
            yield cloneRepository(namespace, config.path);
            yield move(oldDir, dir);
            yield updatePackage(dir, { namespace });
            info("Installing package's dependencies...", logs);
            yield npmInstall(dir, logs);
            success(chalk `Successfully installed {underline.bold ${namespace}}!`, logs);
        }
        catch (e) {
            throw e;
        }
    }
    else {
        error(chalk `Package name '{underline.bold ${namespace}}' is not a GitHub repository`, logs);
    }
});
//# sourceMappingURL=install.js.map