var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import chalk from 'chalk';
import path from 'path';
import install from './install';
import config from '../config';
import { info, success, error } from '../utils/console';
import { remove } from '../utils/files';
import { parseRepository } from '../utils/github';
import { readPackage } from '../utils/packages';
import request from '../utils/request';
export default (namespace, logs = true) => __awaiter(this, void 0, void 0, function* () {
    const { branch, name, owner } = parseRepository(namespace);
    if (name) {
        const pluginPath = path.resolve(config.path, name);
        const { version } = yield readPackage(pluginPath);
        try {
            info(chalk `Checking for updates for package {underline.bold ${namespace}}`, logs);
            const pkgInfo = yield request(`https://api.github.com/repos/${owner}/${name}/contents/package.json?branch=${branch}`);
            const newPkg = yield request(pkgInfo.download_url);
            if (version !== newPkg.version) {
                info(`Current package version: ${version}`, logs);
                info(`New package version: ${newPkg.version}`, logs);
                yield remove(pluginPath);
                yield install(namespace, logs);
                success(chalk `Successfully updated package {underline.bold ${namespace}}!`, logs);
            }
            else {
                success(chalk `Package {underline.bold ${namespace}} is already up to date!`, logs);
            }
        }
        catch (e) {
            throw e;
        }
    }
    error('Invalid package name', logs);
});
//# sourceMappingURL=update.js.map