var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import path from 'path';
import { spawn } from 'child_process';
import { readFile, exists, writeFile } from '../utils/files';
const npm = require('npm');
export function readPackage(dir) {
    return __awaiter(this, void 0, void 0, function* () {
        const packagePath = path.resolve(dir, 'package.json');
        const namespace = path.basename(dir);
        if (yield exists(packagePath)) {
            return JSON.parse(yield readFile(packagePath, 'utf8'));
        }
        throw new Error(`Couldn't find package.json for plugin ${namespace}.`);
    });
}
export function updatePackage(dir, json) {
    return __awaiter(this, void 0, void 0, function* () {
        const pkg = yield readPackage(dir);
        return writeFile(path.resolve(dir, 'package.json'), JSON.stringify(Object.assign({}, pkg, json)));
    });
}
export function getDependencies(dir) {
    return __awaiter(this, void 0, void 0, function* () {
        const pkg = yield readPackage(dir);
        const deps = [];
        for (const key in pkg.dependencies) {
            deps.push(`${key}@${pkg.dependencies[key]}`);
        }
        return deps;
    });
}
export function npmInstall(dir, logs = true) {
    return __awaiter(this, void 0, void 0, function* () {
        return new Promise((resolve, reject) => __awaiter(this, void 0, void 0, function* () {
            const build = spawn('npm', ['install'], {
                cwd: dir,
                shell: true,
            });
            build.on('close', code => {
                if (code === 0) {
                    resolve(code);
                }
                else {
                    reject(code);
                }
            });
        }));
    });
}
//# sourceMappingURL=packages.js.map